@@ -1,4 +1,4 @@
-# gTranscribe is a software focussed on easy transcription of spoken words.
+# gTranscribe is a software focused on easy transcription of spoken words.
 # Copyright (C) 2013-2014 Philip Rinn <rinni@inventati.org>
 # Copyright (C) 2010 Frederik Elwert <frederik.elwert@web.de>
 #
@@ -14,12 +14,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
+#pylint: disable=wrong-import-position
 import logging
 import gi
 gi.require_version('Gst', '1.0')
 from gi.repository import Gst, GObject
 logger = logging.getLogger('player')
-GObject.threads_init()
 Gst.init(None)
 
 
@@ -158,6 +158,7 @@ class gTranscribePlayer(Gst.Bin):
 
     volume = property(_get_volume, _set_volume)
 
+    # pylint: disable=unused-argument
     def on_new_decoded_pad(self, element, pad):
         """
         Handle new decoded pad from decodebin.
@@ -171,6 +172,7 @@ class gTranscribePlayer(Gst.Bin):
                 pad.link(self.apad)
             self.emit('ready', self.filename)
 
+    # pylint: disable=unused-argument
     def on_message(self, bus, message):
         """Handle message and react accordingly."""
         if message.type == Gst.MessageType.EOS:
